==> zio-aws-amplifyuibuilder_3-5.17.147.1-sources.jar: zio/aws/amplifyuibuilder/model/ExportComponentsRequest.scala <==
package zio.aws.amplifyuibuilder.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ExportComponentsRequest(
    appId: String,
    environmentName: String,
    nextToken: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifyuibuilder.model.ExportComponentsRequest = {
    import ExportComponentsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifyuibuilder.model.ExportComponentsRequest
      .builder()
      .appId(appId: java.lang.String)
      .environmentName(environmentName: java.lang.String)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly
      : zio.aws.amplifyuibuilder.model.ExportComponentsRequest.ReadOnly =
    zio.aws.amplifyuibuilder.model.ExportComponentsRequest.wrap(buildAwsValue())
}
object ExportComponentsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifyuibuilder.model.ExportComponentsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifyuibuilder.model.ExportComponentsRequest =
      zio.aws.amplifyuibuilder.model.ExportComponentsRequest(
        appId,
        environmentName,
        nextToken.map(value => value)
      )
    def appId: String
    def environmentName: String
    def nextToken: Option[String]
    def getAppId: ZIO[Any, Nothing, String] = ZIO.succeed(appId)
    def getEnvironmentName: ZIO[Any, Nothing, String] =
      ZIO.succeed(environmentName)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifyuibuilder.model.ExportComponentsRequest
  ) extends zio.aws.amplifyuibuilder.model.ExportComponentsRequest.ReadOnly {
    override val appId: String = impl.appId(): String
    override val environmentName: String = impl.environmentName(): String
    override val nextToken: Option[String] =
      scala.Option(impl.nextToken()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifyuibuilder.model.ExportComponentsRequest
  ): zio.aws.amplifyuibuilder.model.ExportComponentsRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-amplifyuibuilder_3-5.20.37.1-sources.jar: zio/aws/amplifyuibuilder/model/ExportComponentsRequest.scala <==
package zio.aws.amplifyuibuilder.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class ExportComponentsRequest(
    appId: String,
    environmentName: String,
    nextToken: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifyuibuilder.model.ExportComponentsRequest = {
    import ExportComponentsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifyuibuilder.model.ExportComponentsRequest
      .builder()
      .appId(appId: java.lang.String)
      .environmentName(environmentName: java.lang.String)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly
      : zio.aws.amplifyuibuilder.model.ExportComponentsRequest.ReadOnly =
    zio.aws.amplifyuibuilder.model.ExportComponentsRequest.wrap(buildAwsValue())
}
object ExportComponentsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifyuibuilder.model.ExportComponentsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifyuibuilder.model.ExportComponentsRequest =
      zio.aws.amplifyuibuilder.model.ExportComponentsRequest(
        appId,
        environmentName,
        nextToken.map(value => value)
      )
    def appId: String
    def environmentName: String
    def nextToken: Optional[String]
    def getAppId: ZIO[Any, Nothing, String] = ZIO.succeed(appId)
    def getEnvironmentName: ZIO[Any, Nothing, String] =
      ZIO.succeed(environmentName)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifyuibuilder.model.ExportComponentsRequest
  ) extends zio.aws.amplifyuibuilder.model.ExportComponentsRequest.ReadOnly {
    override val appId: String = impl.appId(): String
    override val environmentName: String = impl.environmentName(): String
    override val nextToken: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifyuibuilder.model.ExportComponentsRequest
  ): zio.aws.amplifyuibuilder.model.ExportComponentsRequest.ReadOnly =
    new Wrapper(impl)
}
